function dydt = TDSC_ode_esempio1(t, y, param1, param2)
% ODE dell'esempio 1 - sistema massa-molla-smorzatore
% corso TDSC a.a. 2010/2011
%
% modello in equazioni di stato di un sistema meccanico
% massa-molla-smorzatore
%
% variabili IN: t, y , flag: vedi successivo template ODEFILE di MathWorks
% params: vettore che contiene i valori dei coefficienti dell'equazione
% differenziale del 2.o ordine che descrive il sistema
%
% m y" + b y' + k y = f
%
% param1(1): massa m
% param1(2): costante di attrito viscoso b
% param1(3): costante elastica k
%
%
% param2(1) : forzante f
%             0 -> scalino di ampiezza pari al valore di param2(2)
%             1 -> segnale sinusoidale con ampiezza pari al valore di
%                  param2(2) e frequenza [Hz] pari al valore di param2(3)
%             2 -> combinazione dei precedenti; ampiezza dello scalino in
%                  param2(2), della sinusoide in param2(3), frequenza [Hz] 
%                  della sinusoide in param2(4)
%
%
% variabili OUT: dydt derivata prima delle variabili y
%

 
% --------------------------------------------------------
% il sistema di equazioni differenziali che descrive il sistema
 m = param1(1); beta = param1(2); k = param1(3);
% param2(1) : forzante f
%             0 -> scalino di ampiezza pari al valore di param2(2)
%             1 -> segnale sinusoidale con ampiezza pari al valore di
%                  param2(2) e frequenza [Hz] pari al valore di param2(3)
%             2 -> combinazione dei precedenti; ampiezza dello scalino in
%                  param2(2), della sinusoide in param2(3), frequenza [Hz] 
%                  della sinusoide in param2(4)
f_id = param2(1);
switch f_id
    case 0
        f = param2(2);
    case 1
        f = param2(2) * sin(2*pi*param2(3)*t);
    case 2
        f = param2(2) + param2(3) * sin(2*pi*param2(4)*t);
end % case

 dydt = [y(2); (-beta*y(2) - k * y(1) + f)/m];
 % m y" + b y' + k y = f

% --------------------------------------------------------
