function dydt = TDSC_ode_esempio2(t, y, param1, param2)
% ODE dell'esempio 2 - sistema massa-molla-smorzatore
% corso TDSC a.a. 2010/2011
%
% modello in equazioni di stato di un sistema meccanico
% massa-molla-smorzatore
%
% variabili IN: t, y 
% params: vettore che contiene i valori dei coefficienti dell'equazione
% differenziale  che descrive il sistema
%
% 
%
% param1(1:3): masse m1 m2 m3
% param1(4:5): costante di attrito viscoso b2 b3
% param1(6:7): costante elastica k2 k3
% param1(8)  : costante tau
%
%
% param2(1) : forzante f
%             0 -> scalino di ampiezza pari al valore di param2(2)
%             1 -> segnale sinusoidale con ampiezza pari al valore di
%                  param2(2) e frequenza [Hz] pari al valore di param2(3)
%             2 -> combinazione dei precedenti; ampiezza dello scalino in
%                  param2(2), della sinusoide in param2(3), frequenza [Hz] 
%                  della sinusoide in param2(4)
%
%
% variabili OUT: dydt derivata prima delle variabili y
%

 
% --------------------------------------------------------
% il sistema di equazioni differenziali che descrive il sistema
 m1 = param1(1); m2 = param1(2); m3 = param1(3); 
 b2 = param1(4); b3 = param1(5);
 k2 = param1(6); k3 = param1(7);
 tau = param1(8);

f_id = param2(1);
switch f_id
    case 0
        f = param2(2);
    case 1
        f = param2(2) * sin(2*pi*param2(3)*t);
    case 2
        f = param2(2) + param2(3) * sin(2*pi*param2(4)*t);
end % case

 dydt = [y(2);...
         f/m1-(k2*(y(3)-y(1)/tau)+b2*(y(4)-y(2)/tau))/(tau*m1);...
         y(4);...
         (k3*(y(5)-y(3)+b3*(y(6)-y(4)))/m2-(k2/m2)*(y(3)-y(1)/tau)+(b2/m2)*(y(4)-y(2)/tau));...
         y(6);...
         -(k3/m3)*(y(5)-y(3))-(b3/m3)*(y(6)-y(4))];

% --------------------------------------------------------
