function dydt = TDSC_ode_esempio3(t, y, param1)
% ODE dell'esempio 3 - sistema pendolo semplice
% corso TDSC a.a. 2010/2011
%
% modello in equazioni di stato di un sistema meccanico
% pendolo semplice inverso
%
% variabili IN: t, y 
% param1: vettore che contiene i valori dei coefficienti dell'equazione
% differenziale  che descrive il sistema
%
% param1(1): massa m
% param1(2): lunghezza l
% param1(3): costante di attrito viscoso b
% param1(4): modulo della forza
% param1(5): intervallo di applicazione della forza
%
% variabili OUT: dydt derivata prima delle variabili y
%
persistent T0

if isempty(T0)
    T0 = t;
end % if
 g = 9.80665; % accelerazione di gravita'
% --------------------------------------------------------
% il sistema di equazioni differenziali che descrive il sistema
 m = param1(1); l = param1(2); b = param1(3); 

% forzante d'ingresso: pari a F [N] per i primi 5 secondi, poi nulla
F_val = param1(4); % forza in N
t_F = param1(5); % la forza e' non nulla nell'intervallo [t0, t0+t_F], con t0 istante iniziale
if (t <= (T0+t_F))
    f = F_val;
else
    f= 0;
end % if

 dydt = [y(2);...
         -(g/l)*sin(y(1))-(b/m/l^2)*y(2)+f/m/l^2];

% --------------------------------------------------------
